@@ -1,20 +1,27 @@
-# Copyright (c) 2012, cPanel, Inc.
+# Copyright (c) 2014, cPanel, Inc.
 # All rights reserved.
 # http://cpanel.net/
 #
 # This is free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.  See the LICENSE file for further details.
 
-package Filesys::POSIX;
+package Filesys::POSIX::Mount;
 
 use strict;
 use warnings;
 
 use Filesys::POSIX::Bits;
-use Filesys::POSIX::Path ();
+use Filesys::POSIX::Module ();
+use Filesys::POSIX::Path   ();
+
+use Filesys::POSIX::Error qw(throw);
 
 use Carp qw/confess/;
 
+my @METHODS = qw(mount unmount statfs fstatfs mountlist);
+
+Filesys::POSIX::Module->export_methods( __PACKAGE__, @METHODS );
+
 =head1 NAME
 
 Filesys::POSIX::Mount - Exposes VFS mounting functionality to L<Filesys::POSIX>
@@ -73,10 +80,10 @@ checks.
 
 =item The file descriptor table is scanned for open files whose inodes exist on
 the device found for the mount record queried in the previous step by the VFS.
-An exception is thrown when matching file descriptors are found.
+An EBUSY exception is thrown when matching file descriptors are found.
 
 =item The current working directory is checked to ensure it is not a reference
-to a directory inode associated with the mounted device.  An exception is
+to a directory inode associated with the mounted device.  An EBUSY exception is
 thrown if the current directory is on the same device that is to be unmounted.
 
 =back
@@ -94,14 +101,14 @@ sub unmount {
     foreach ( $self->{'fds'}->list ) {
         my $inode = $self->{'fds'}->lookup($_)->{'inode'};
 
-        confess('Device or resource busy') if $mount->{'dev'} eq $inode->{'dev'};
+        throw &Errno::EBUSY if $mount->{'dev'} eq $inode->{'dev'};
     }
 
     #
     # Next, check to see if the current working directory's device inode
     # is the same device as the one being requested for unmounting.
     #
-    confess('Device or resource busy') if $mount->{'dev'} eq $self->{'cwd'}->{'dev'};
+    throw &Errno::EBUSY if $mount->{'dev'} eq $self->{'cwd'}->{'dev'};
 
     $self->{'vfs'}->unmount($mount);
 }
@@ -203,3 +210,24 @@ A copy of the options passed to C<$fs-E<gt>mount>, minus the C<special> option.
 =cut
 
 1;
+
+__END__
+
+=head1 AUTHOR
+
+Written by Xan Tronix <xan@cpan.org>
+
+=head1 CONTRIBUTORS
+
+=over
+
+=item Rikus Goodell <rikus.goodell@cpanel.net>
+
+=item Brian Carlson <brian.carlson@cpanel.net>
+
+=back
+
+=head1 COPYRIGHT
+
+Copyright (c) 2014, cPanel, Inc.  Distributed under the terms of the Perl
+Artistic license.
